<?php

namespace Drupal\barclaycard_epdq;

/**
 * Trait BarclaycardEdpqTrait.
 *
 * @package Drupal\barclaycard_epdq
 */
trait BarclaycardEdpqTrait {

  /**
   * Creates a SHA1 hash digest.
   *
   * The SHA1 hashed string consists of key = value pairs followed
   * by the SHA passphrase for each item. This is used to confirm
   * that the data has not been tampered with.
   *
   * @param array $data
   *   The data.
   * @param string $sha_passphrase
   *   The SHA passphrase.
   *
   * @return string
   *   The SHA1 hash digest.
   */
  private function getShaSignature(array $data, string $sha_passphrase) {
    $sha_signature = '';

    foreach ($data as $key => $value) {
      if ($value === NULL || $value === '') {
        continue;
      }

      $sha_signature .= $key . '=' . $value . $sha_passphrase;
    }

    $sha_signature = hash('sha1', $sha_signature);

    return $sha_signature;
  }

}
