<?php

namespace Drupal\barclaycard_epdq\PluginForm;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\barclaycard_epdq\BarclaycardEdpqTrait;
use Drupal\commerce_payment\PluginForm\PaymentOffsiteForm;

/**
 * Class BarclaycardEpdqPaymentForm.
 *
 * @package Drupal\barclaycard_epdq\PluginForm
 */
class BarclaycardEpdqPaymentForm extends PaymentOffsiteForm {

  use BarclaycardEdpqTrait;

  /**
   * A config entity.
   *
   * @var Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * Initializes two class properties.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config
   *   The config factory.
   */
  private function setUp(ConfigFactoryInterface $config) {
    $this->config = $config->get('commerce_payment.commerce_payment_gateway.barclaycard_epdq');
  }

  /**
   * BarclaycardEpdqPaymentForm constructor.
   */
  public function __construct() {
    $this->setUp(\Drupal::service('config.factory'));
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildConfigurationForm($form, $form_state);
    $payment = $this->entity;
    $amount = $payment->getAmount();
    /** @var \Drupal\commerce_order\Entity\Order $order */
    $order = $payment->getOrder();
    $redirection_url = $this->config->get('configuration.redirect_url');
    $accept_url = $this->config->get('configuration.accept_url');
    $cancel_url = $this->config->get('configuration.cancel_url');
    $vat_percentage = $this->config->get('configuration.vat_percentage');
    $amount = ($payment->getBalance()->getNumber() * 100);
    if ($vat_percentage) {
      $vat_decimal = ($vat_percentage / 100);
      $amount += ($vat_decimal * $amount);
    }

    // @todo replace 'en_GB' with site language.
    $data = [
      'AMOUNT'       => $amount,
      'CURRENCY'     => $amount->getCurrencyCode(),
      'LANGUAGE'     => 'en_GB',
      'ORDERID'      => $order->id(),
      'PSPID'        => $this->config->get('configuration.pspid'),
      'ACCEPTURL'    => $accept_url ? $accept_url : $form['#return_url'],
      'DECLINEURL'   => $this->config->get('configuration.decline_url'),
      'EXCEPTIONURL' => $this->config->get('configuration.exception_url'),
      'CANCELURL'    => $cancel_url ? $cancel_url : $form['#cancel_url'],
      'BACKURL'      => $this->config->get('configuration.back_url'),
      'HOMEURL'      => $this->config->get('configuration.home_url'),
    ];

    ksort($data);
    $sha_in_passphrase = $this->config->get('configuration.sha_in_passphrase');
    $sha_signature = $this->getShaSignature($data, (string) $sha_in_passphrase);
    $data['SHASIGN'] = $sha_signature;

    $redirect_form = $this->buildRedirectForm(
      $form,
      $form_state,
      $redirection_url,
      $data,
      PaymentOffsiteForm::REDIRECT_POST
    );

    return $redirect_form;
  }

}
